Module watch

Module watch 

A synchronization primitive for passing the latest value to multiple receivers.

Structs

Rcv
A receiver can get a change in the Watch value.
Receiver
A receiver of a Watch channel.
Sender
A sender of a Watch channel.
Snd
A receiver can .await a change in the Watch value.
Watch
The Watch is a single-slot signaling primitive that allows multiple (N) receivers to get changes to the value. Unlike a Signal, Watch supports multiple receivers, and unlike a PubSubChannel, Watch immediately overwrites the previous value when a new one is sent, without waiting for all receivers to read the previous value.

Traits

WatchBehavior
A trait representing the ‘inner’ behavior of the Watch.