Modules
- signal
- A synchronization primitive for passing the latest value to a task.
- watch
- A synchronization primitive for passing the latest value to multiple receivers.
Structs
- Noop
Sync RawMutex - A mutex that allows borrowing data in a global context.